@@ -9,8 +9,6 @@
 # @author D. Arnold
 # @since 2006-05-01
 # @self $self
-#
-# maintenance and modifications - Athanasios Douitsis aduitsis@cpan.org
 #*/
 package IPC::Mmap::POSIX;
 #
@@ -19,17 +17,13 @@ package IPC::Mmap::POSIX;
 use Carp;
 use Fcntl qw(:flock :mode);
 use FileHandle;
-use IPC::SysV qw(IPC_PRIVATE IPC_CREAT);
-use IPC::Semaphore;
 use IPC::Mmap;
-use FindBin qw($Bin $Script);
 use IPC::Mmap qw(MAP_ANON MAP_ANONYMOUS MAP_FILE MAP_PRIVATE MAP_SHARED
 	PROT_READ PROT_WRITE);
 use base qw(IPC::Mmap);
 
 use strict;
 use warnings;
-use Data::Dumper;
 
 #use constant MAP_ANON => constant('MAP_ANON', 0);
 #use constant MAP_ANONYMOUS => constant('MAP_ANONYMOUS', 0);
@@ -39,7 +33,7 @@ use Data::Dumper;
 #use constant PROT_READ  => constant('PROT_READ', 0);
 #use constant PROT_WRITE => constant('PROT_WRITE', 0);
 
-our $VERSION = '0.22_02';
+our $VERSION = '0.11';
 #/**
 # Constructor. mmap()'s using POSIX mmap().
 #
@@ -55,47 +49,6 @@ sub new {
 
 	my $fh;
 
-	#the MAN_ANON case will be handled independentlY
-	if($mmap & MAP_ANON) {
-		#make sure we weren't given something that is not a pathname
-		croak 'When using anonymous mmap, only a pathname is allowed as the first argument' unless (ref($file) eq '');
-
-		#if the file doesn't exist, just touch it
-		if(! -e $file) {
-			open(my $fd,'>',$file) or croak $!;
-			close $fd;
-		}
-		if(! -r $file) {
-			croak "For anonymous mmap, you must provide an readable filename in order for the ftok(3) to return a valid unique id. Unfortunately $file doesn't seem to be readable. ";
-		}
-
-		my $unique_id = IPC::SysV::ftok($file,1);
-		
-		#create a brand new semaphore 
-		my $sem = new IPC::Semaphore($unique_id, 1, 0666|IPC_CREAT) or croak "Cannot create semaphore:$!";
-		####print STDERR "semaphore is ".Dumper($sem)." \n";
-
-		#make sure its released
-		$sem->op(0,1,0) or croak "Cannot op(0,1,0) on sem";
-		#@@#warn "semaphore value is ",$sem->getval(0),"\n";
-
-		my ($mapaddr, $maxlen, $slop) = _mmap_anon($length, $prot, $mmap);
-		croak "mmap() failed" unless defined($mapaddr);
-		my $self = {
-			_fh => $fh,
-			_file => $file,
-			_mmap => $mmap,
-			_access => $prot,
-			_addr => $mapaddr,
-			_maxlen => $maxlen,
-			_slop => $slop,
-			semaphore => $sem,
-		};
-
-	return bless $self, $class;
-	}
-
-
 	croak 'No filename or filehandle provided.'
 		unless defined($file) || ($mmap & MAP_ANON);
 
@@ -150,13 +103,6 @@ sub new {
 	return bless $self, $class;
 }
 
-sub DESTROY {
-	if(defined($_[0]->{semaphore})) {
-		print STDERR "destroying semaphore ".Dumper($_[0]->{semaphore})."\n";
-		$_[0]->{semaphore}->remove;
-	}
-}
-
 #/**
 # Locks the mmap'ed region. Implemented using flock()
 # on the mmap()'ed file.
@@ -173,16 +119,9 @@ sub DESTROY {
 sub lock {
 	my ($self, $offset, $len) = @_;
 
-	if(defined($self->{semaphore})) {
-		#acquire
-		$self->{semaphore}->op(0,-1,0) or croak("Cannot op(0,-1,0) on sem");
-		#@@#warn "semaphore acquired";
-		return 1;
-	}
-			
 	my $fh = $self->{_fh};
-	my $mmode = ($self->{_access} == PROT_READ) ? LOCK_SH : LOCK_EX;
-	return flock($fh, $mmode);
+	my $mode = ($self->{_access} & PROT_READ) ? LOCK_SH : LOCK_EX;
+	return flock($fh, $mode);
 }
 
 #/**
@@ -192,13 +131,6 @@ sub lock {
 sub unlock {
 	my ($self, $offset, $len) = @_;
 
-	if(defined($self->{semaphore})) {
-		#release
-		$self->{semaphore}->op(0,1,0) or croak("Cannot op(0,1,0) on sem");
-		#@@#warn "semaphore released";
-		return 1;
-	}
-
 	my $fh = $self->{_fh};
 	return flock($fh, LOCK_UN);
 }
